.. highlight:: shell

============
Installation
============

At the command line:

.. code-block:: console

    $ easy_install sabat

Or, if you have virtualenvwrapper installed:

.. code-block:: console

    $ mkvirtualenv sabat
    $ pip install sabat
